@@ -25,3 +25,12 @@ class NewUSDPriceMessage(BaseEventMessage):
 
 class NewPriceReferenceMessage(BaseEventMessage):
     prices: Dict[str, float]
+
+    
+class NewPriceMinimumDeltaMessage(BaseEventMessage):
+    market_code: str
+    minimum_delta: float
+
+class NewOrderBookDephMessage(BaseEventMessage):
+    market_code:str
+    depth: float
