@@ -37,6 +37,17 @@ class OrderFilledMessage(BaseEventMessage):
     limit_price: Optional[float]
 
 
+class TradeMessage(BaseEventMessage):
+    exchange: str
+    order_id: str
+    transaction_id: str
+    market_code: str
+    type: str
+    selling: str
+    amount: float
+    limit_price: float
+
+
 class WalletBalanceUpdate(BaseEventMessage):
     exchange: str
     currency_code: str
